@@ -88,6 +88,7 @@ class monitoring2:
 	user_by_mail(mail) - Поиск пользователя по почте
 	user_by_id(id) - Поиск пользователя по id
 	change_tenant(org_id, tenant_id) - Смена тенанта организации по id
+	check_promo(promo_id) - Проверка КА по id или полному коду
 	'''
 
 	def __init__(self, login, password, url = 'http://taxplayer.ensyco.local', crpt = False, echo = True):
@@ -273,6 +274,14 @@ class monitoring2:
 		self.r = self.ms.post('{}/api/organisations/changetenant'.format(self.URL), json=form)
 		return self.logger('Меняем тенант организации {} на {}...'.format(org_id, tenant_id))
 
+	def check_promo(self, promo_id):
+		'''
+		Проверка КА по id или полному коду
+		'''
+		if len(promo_id) >= 13: promo_id=promo_id[:len(promo_id)-10]
+		self.r = self.ms.get('{}/api/promo/{}'.format(self.URL, promo_id))
+		return self.logger('Проверяем КА {}...'.format(promo_id))
+
 class prodRf:
 
 	help = '''
